summaryrefslogtreecommitdiffstats
path: root/openstack
diff options
context:
space:
mode:
authorRussell Bryant <rbryant@redhat.com>2012-06-13 11:11:01 -0400
committerRussell Bryant <rbryant@redhat.com>2012-06-13 11:13:41 -0400
commit7e1631606d642f0def75d684e92f0d3d52501de5 (patch)
tree59a9e8fd7c3d7a4cef347fb2edec26c214873268 /openstack
parent91fc479399ab12d8ba670c3627582ebfc3950af8 (diff)
downloadoslo-7e1631606d642f0def75d684e92f0d3d52501de5.tar.gz
oslo-7e1631606d642f0def75d684e92f0d3d52501de5.tar.xz
oslo-7e1631606d642f0def75d684e92f0d3d52501de5.zip
Fix nova.rpc references in comments.
Part of blueprint common-rpc. Strip remaining references to 'nova.rpc' that existed in comments. Change-Id: I27885918a5e38eb730504c9e88bdda2b72b23257
Diffstat (limited to 'openstack')
-rw-r--r--openstack/common/rpc/__init__.py30
-rw-r--r--openstack/common/rpc/amqp.py2
2 files changed, 18 insertions, 14 deletions
diff --git a/openstack/common/rpc/amqp.py b/openstack/common/rpc/amqp.py
index a79a3aa..c61762e 100644
--- a/openstack/common/rpc/amqp.py
+++ b/openstack/common/rpc/amqp.py
@@ -18,7 +18,7 @@
# under the License.
"""
-Shared code between AMQP based nova.rpc implementations.
+Shared code between AMQP based openstack.common.rpc implementations.
The code in this module is shared between the rpc implemenations based on AMQP.
Specifically, this includes impl_kombu and impl_qpid. impl_carrot also uses
diff --git a/openstack/common/rpc/__init__.py b/openstack/common/rpc/__init__.py
index 169aeca..5cde075 100644
--- a/openstack/common/rpc/__init__.py
+++ b/openstack/common/rpc/__init__.py
@@ -72,7 +72,7 @@ def create_connection(new=True):
implementation is free to return an existing connection from a
pool.
:returns: An instance of nova.rpc.common.Connection
"""
return _get_impl().create_connection(cfg.CONF, new=new)
@@ -84,8 +84,9 @@ def call(context, topic, msg, timeout=None):
request.
:param topic: The topic to send the rpc message to. This correlates to the
topic argument of
- nova.rpc.common.Connection.create_consumer() and only applies
- when the consumer was created with fanout=False.
+ openstack.common.rpc.common.Connection.create_consumer()
+ and only applies when the consumer was created with
+ fanout=False.
:param msg: This is a dict in the form { "method" : "method_to_invoke",
"args" : dict_of_kwargs }
:param timeout: int, number of seconds to use for a response timeout.
@@ -93,8 +94,8 @@ def call(context, topic, msg, timeout=None):
:returns: A dict from the remote method.
:raises: nova.rpc.common.Timeout if a complete response is not received
before the timeout is reached.
"""
return _get_impl().call(cfg.CONF, context, topic, msg, timeout)
@@ -106,8 +107,9 @@ def cast(context, topic, msg):
request.
:param topic: The topic to send the rpc message to. This correlates to the
topic argument of
- nova.rpc.common.Connection.create_consumer() and only applies
- when the consumer was created with fanout=False.
+ openstack.common.rpc.common.Connection.create_consumer()
+ and only applies when the consumer was created with
+ fanout=False.
:param msg: This is a dict in the form { "method" : "method_to_invoke",
"args" : dict_of_kwargs }
@@ -126,8 +128,9 @@ def fanout_cast(context, topic, msg):
request.
:param topic: The topic to send the rpc message to. This correlates to the
topic argument of
- nova.rpc.common.Connection.create_consumer() and only applies
- when the consumer was created with fanout=True.
+ openstack.common.rpc.common.Connection.create_consumer()
+ and only applies when the consumer was created with
+ fanout=True.
:param msg: This is a dict in the form { "method" : "method_to_invoke",
"args" : dict_of_kwargs }
@@ -147,8 +150,9 @@ def multicall(context, topic, msg, timeout=None):
request.
:param topic: The topic to send the rpc message to. This correlates to the
topic argument of
- nova.rpc.common.Connection.create_consumer() and only applies
- when the consumer was created with fanout=False.
+ openstack.common.rpc.common.Connection.create_consumer()
+ and only applies when the consumer was created with
+ fanout=False.
:param msg: This is a dict in the form { "method" : "method_to_invoke",
"args" : dict_of_kwargs }
:param timeout: int, number of seconds to use for a response timeout.
@@ -159,8 +163,8 @@ def multicall(context, topic, msg, timeout=None):
returned and X is the Nth value that was returned by the remote
method.
:raises: nova.rpc.common.Timeout if a complete response is not received
before the timeout is reached.
"""
return _get_impl().multicall(cfg.CONF, context, topic, msg, timeout)
@@ -72,7 +72,7 @@ def create_connection(new=True):
implementation is free to return an existing connection from a
pool.
- :returns: An instance of nova.rpc.common.Connection
+ :returns: An instance of openstack.common.rpc.common.Connection
"""
return _get_impl().create_connection(cfg.CONF, new=new)
@@ -93,8 +94,8 @@ def call(context, topic, msg, timeout=None):
:returns: A dict from the remote method.
- :raises: nova.rpc.common.Timeout if a complete response is not received
- before the timeout is reached.
+ :raises: openstack.common.rpc.common.Timeout if a complete response
+ is not received before the timeout is reached.
"""
return _get_impl().call(cfg.CONF, context, topic, msg, timeout)
@@ -159,8 +163,8 @@ def multicall(context, topic, msg, timeout=None):
returned and X is the Nth value that was returned by the remote
method.
- :raises: nova.rpc.common.Timeout if a complete response is not received
- before the timeout is reached.
+ :raises: openstack.common.rpc.common.Timeout if a complete response
+ is not received before the timeout is reached.
"""
return _get_impl().multicall(cfg.CONF, context, topic, msg, timeout)